Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJason Wilkins <Jason.A.Wilkins@gmail.com>2014-10-23 05:03:25 +0400
committerJason Wilkins <Jason.A.Wilkins@gmail.com>2014-10-23 05:03:25 +0400
commit88fe8962434b7fe00fa713a84c58d2dbee481e3b (patch)
tree1a5a51cadd78e258924a13f0d1adcc1ebd7f6a0d /extern/glew-es
parentdb8e6311f899819dba509d516654071edd42fa54 (diff)
Checked each of my (jwilkins) XXX notes.
The ones in extern/glew-es have been changed to NOTE instead of XXX GHOST_ContextEGL.cpp: It really does seem that it is not possible to query the swap interval using EGL GHOST_WidnowCocoa.h: The comment referring to Carbon is clearly out of date, so I removed it. math_geom.c: The node about not using tmax again is correct, but the code is kept for a future maintainer who will need to know how to compute it if they modify that code. paint_image_proj.c (2698): The question about integer truncation does not appear to have been resolved. It still seems to be an incorrectly implementation of rounding (I'd suggest using the round function instead of this hack).
Diffstat (limited to 'extern/glew-es')
-rw-r--r--extern/glew-es/include/GL/eglew.h18
-rw-r--r--extern/glew-es/include/GL/glesew.h150
-rw-r--r--extern/glew-es/include/GL/glew.h14
-rw-r--r--extern/glew-es/include/GL/wglew.h8
-rw-r--r--extern/glew-es/src/glew.c90
5 files changed, 140 insertions, 140 deletions
diff --git a/extern/glew-es/include/GL/eglew.h b/extern/glew-es/include/GL/eglew.h
index 14d4dc4f5eb..e1eb1be44d1 100644
--- a/extern/glew-es/include/GL/eglew.h
+++ b/extern/glew-es/include/GL/eglew.h
@@ -594,9 +594,9 @@ typedef EGLBoolean (EGLAPIENTRY * PFNWAITSYNC ) (EGLDisplay dp
#if !defined(EGL_ANDROID_blob_cache)
#define EGL_ANDROID_blob_cache 1
-typedef khronos_ssize_t EGLsizeiANDROID; // XXX jwilkins: missing typedef
-typedef EGLsizeiANDROID (*EGLGetBlobFuncANDROID) (const void* key, EGLsizeiANDROID keySize, void* value, EGLsizeiANDROID valueSize); // XXX jwilkins: missing typedef
-typedef void (*EGLSetBlobFuncANDROID) (const void* key, EGLsizeiANDROID keySize, const void* value, EGLsizeiANDROID valueSize); // XXX jwilkins: missing typedef
+typedef khronos_ssize_t EGLsizeiANDROID; // NOTE jwilkins: missing typedef
+typedef EGLsizeiANDROID (*EGLGetBlobFuncANDROID) (const void* key, EGLsizeiANDROID keySize, void* value, EGLsizeiANDROID valueSize); // NOTE jwilkins: missing typedef
+typedef void (*EGLSetBlobFuncANDROID) (const void* key, EGLsizeiANDROID keySize, const void* value, EGLsizeiANDROID valueSize); // NOTE jwilkins: missing typedef
typedef void (EGLAPIENTRY * PFNEGLSETBLOBCACHEFUNCSANDROIDPROC) (EGLDisplay dpy, EGLSetBlobFuncANDROID set, EGLGetBlobFuncANDROID get);
@@ -633,7 +633,7 @@ typedef void (EGLAPIENTRY * PFNEGLSETBLOBCACHEFUNCSANDROIDPROC) (EGLDisplay dpy,
#if !defined(EGL_ANDROID_native_fence_sync)
#define EGL_ANDROID_native_fence_sync 1
-typedef void* EGLSyncKHR; // XXX jwilkins: missing typedef
+typedef void* EGLSyncKHR; // NOTE jwilkins: missing typedef
#define EGL_SYNC_NATIVE_FENCE_ANDROID 0x3144
#define EGL_SYNC_NATIVE_FENCE_FD_ANDROID 0x3145
@@ -1013,7 +1013,7 @@ typedef EGLBoolean (EGLAPIENTRY * PFNEGLSIGNALSYNCKHRPROC) (EGLDisplay dpy, EGLS
#define EGL_CONSUMER_ACQUIRE_TIMEOUT_USEC_KHR 0x321E
-typedef void* EGLStreamKHR; // XXX jwilkins: missing typedef
+typedef void* EGLStreamKHR; // NOTE jwilkins: missing typedef
typedef EGLBoolean (EGLAPIENTRY * PFNEGLSTREAMCONSUMERACQUIREKHRPROC) (EGLDisplay dpy, EGLStreamKHR stream);
typedef EGLBoolean (EGLAPIENTRY * PFNEGLSTREAMCONSUMERGLTEXTUREEXTERNALKHRPROC) (EGLDisplay dpy, EGLStreamKHR stream);
@@ -1032,7 +1032,7 @@ typedef EGLBoolean (EGLAPIENTRY * PFNEGLSTREAMCONSUMERRELEASEKHRPROC) (EGLDispla
#if !defined(EGL_KHR_stream_cross_process_fd)
#define EGL_KHR_stream_cross_process_fd 1
-typedef int EGLNativeFileDescriptorKHR; // XXX jwilkins: missing typedef
+typedef int EGLNativeFileDescriptorKHR; // NOTE jwilkins: missing typedef
typedef EGLStreamKHR (EGLAPIENTRY * PFNEGLCREATESTREAMFROMFILEDESCRIPTORKHRPROC) (EGLDisplay dpy, EGLNativeFileDescriptorKHR file_descriptor);
typedef EGLNativeFileDescriptorKHR (EGLAPIENTRY * PFNEGLGETSTREAMFILEDESCRIPTORKHRPROC) (EGLDisplay dpy, EGLStreamKHR stream);
@@ -1107,7 +1107,7 @@ typedef EGLSurface (EGLAPIENTRY * PFNEGLCREATESTREAMPRODUCERSURFACEKHRPROC) (EGL
#if !defined(EGL_KHR_wait_sync)
#define EGL_KHR_wait_sync 1
-typedef void* EGLSyncKHR; // XXX jwilkins: missing typedef
+typedef void* EGLSyncKHR; // NOTE jwilkins: missing typedef
typedef EGLint (EGLAPIENTRY * PFNEGLWAITSYNCKHRPROC) (EGLDisplay dpy, EGLSyncKHR sync, EGLint flags);
@@ -1452,8 +1452,8 @@ extern GLboolean eglewContextIsSupported (const EGLEWContext* ctx, const char* n
#define EGLEW_GET_VAR(x) (*(const GLboolean*)&x)
#define EGLEW_GET_FUN(x) x
-extern GLenum eglewContextInit(EGLDisplay display); // XXX jwilkins: context handling not really written yet?
-#define eglewInit eglewContextInit // XXX jwilkins: context handling not really written yet?
+extern GLenum eglewContextInit(EGLDisplay display); // NOTE jwilkins: context handling not really written yet?
+#define eglewInit eglewContextInit // NOTE jwilkins: context handling not really written yet?
extern GLboolean eglewIsSupported (const char* name);
diff --git a/extern/glew-es/include/GL/glesew.h b/extern/glew-es/include/GL/glesew.h
index 86bdd347f37..0cb8c0d850c 100644
--- a/extern/glew-es/include/GL/glesew.h
+++ b/extern/glew-es/include/GL/glesew.h
@@ -64,22 +64,22 @@
#error glesew.h included instead of glew.h
#endif
-// XXX jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
+// NOTE jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
#ifndef GL_ES_VERSION_1_0 // XXX
#define GL_ES_VERSION_1_0 1 // XXX
#endif // XXX
-// XXX jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
+// NOTE jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
#ifndef GL_ES_VERSION_CL_1_1 // XXX
#define GL_ES_VERSION_CL_1_1 1 // XXX
#endif // XXX
-// XXX jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
+// NOTE jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
#ifndef GL_ES_VERSION_CM_1_1 // XXX
#define GL_ES_VERSION_CM_1_1 1 // XXX
#endif // XXX
-// XXX jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
+// NOTE jwilkins: changing versions from 'ifdef' to 'if' requires setting defaults
#ifndef GL_ES_VERSION_2_0 // XXX
#define GL_ES_VERSION_2_0 1 // XXX
#endif // XXX
@@ -108,7 +108,7 @@ typedef int GLclampx;
/* Internal convenience typedefs */
typedef void (*_GLfuncptr)();
-// XXX jwilkins: had to add these
+// NOTE jwilkins: had to add these
#if defined(_MSC_VER) && _MSC_VER < 1400
typedef __int64 GLint64EXT;
typedef unsigned __int64 GLuint64EXT;
@@ -528,7 +528,7 @@ typedef struct __GLsync *GLsync;
/*************************************************************/
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glAlphaFunc (GLenum func, GLclampf ref);
#endif // XXX
GLAPI void GLAPIENTRY glBindTexture (GLenum target, GLuint texture);
@@ -536,11 +536,11 @@ GLAPI void GLAPIENTRY glBlendFunc (GLenum sfactor, GLenum dfactor);
GLAPI void GLAPIENTRY glClear (GLbitfield mask);
GLAPI void GLAPIENTRY glClearColor (GLclampf red, GLclampf green, GLclampf blue, GLclampf alpha);
GLAPI void GLAPIENTRY glClearStencil (GLint s);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glColor4f (GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
#endif
GLAPI void GLAPIENTRY glColorMask (GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glColorPointer (GLint size, GLenum type, GLsizei stride, const GLvoid *pointer);
#endif
GLAPI void GLAPIENTRY glCopyTexImage2D (GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
@@ -550,18 +550,18 @@ GLAPI void GLAPIENTRY glDeleteTextures (GLsizei n, const GLuint *textures);
GLAPI void GLAPIENTRY glDepthFunc (GLenum func);
GLAPI void GLAPIENTRY glDepthMask (GLboolean flag);
GLAPI void GLAPIENTRY glDisable (GLenum cap);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glDisableClientState (GLenum array);
#endif
GLAPI void GLAPIENTRY glDrawArrays (GLenum mode, GLint first, GLsizei count);
GLAPI void GLAPIENTRY glDrawElements (GLenum mode, GLsizei count, GLenum type, const GLvoid *indices);
GLAPI void GLAPIENTRY glEnable (GLenum cap);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glEnableClientState (GLenum array);
#endif
GLAPI void GLAPIENTRY glFinish (void);
GLAPI void GLAPIENTRY glFlush (void);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glFogf (GLenum pname, GLfloat param);
GLAPI void GLAPIENTRY glFogfv (GLenum pname, const GLfloat *params);
#endif
@@ -571,14 +571,14 @@ GLAPI GLenum GLAPIENTRY glGetError (void);
GLAPI void GLAPIENTRY glGetIntegerv (GLenum pname, GLint *params);
GLAPI const GLubyte * GLAPIENTRY glGetString (GLenum name);
GLAPI void GLAPIENTRY glHint (GLenum target, GLenum mode);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glLightModelf (GLenum pname, GLfloat param);
GLAPI void GLAPIENTRY glLightModelfv (GLenum pname, const GLfloat *params);
GLAPI void GLAPIENTRY glLightf (GLenum light, GLenum pname, GLfloat param);
GLAPI void GLAPIENTRY glLightfv (GLenum light, GLenum pname, const GLfloat *params);
#endif
GLAPI void GLAPIENTRY glLineWidth (GLfloat width);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glLoadIdentity (void);
GLAPI void GLAPIENTRY glLoadMatrixf (const GLfloat *m);
GLAPI void GLAPIENTRY glLogicOp (GLenum opcode);
@@ -591,27 +591,27 @@ GLAPI void GLAPIENTRY glNormal3f (GLfloat nx, GLfloat ny, GLfloat nz);
GLAPI void GLAPIENTRY glNormalPointer (GLenum type, GLsizei stride, const GLvoid *pointer);
#endif
GLAPI void GLAPIENTRY glPixelStorei (GLenum pname, GLint param);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glPointSize (GLfloat size);
#endif // XXX
GLAPI void GLAPIENTRY glPolygonOffset (GLfloat factor, GLfloat units);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glPopMatrix (void);
GLAPI void GLAPIENTRY glPushMatrix (void);
#endif
GLAPI void GLAPIENTRY glReadPixels (GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLvoid *pixels);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glRotatef (GLfloat angle, GLfloat x, GLfloat y, GLfloat z);
GLAPI void GLAPIENTRY glScalef (GLfloat x, GLfloat y, GLfloat z);
#endif
GLAPI void GLAPIENTRY glScissor (GLint x, GLint y, GLsizei width, GLsizei height);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glShadeModel (GLenum mode);
#endif // XXX
GLAPI void GLAPIENTRY glStencilFunc (GLenum func, GLint ref, GLuint mask);
GLAPI void GLAPIENTRY glStencilMask (GLuint mask);
GLAPI void GLAPIENTRY glStencilOp (GLenum fail, GLenum zfail, GLenum zpass);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glTexCoordPointer (GLint size, GLenum type, GLsizei stride, const GLvoid *pointer);
GLAPI void GLAPIENTRY glTexEnvf (GLenum target, GLenum pname, GLfloat param);
GLAPI void GLAPIENTRY glTexEnvfv (GLenum target, GLenum pname, const GLfloat *params);
@@ -619,7 +619,7 @@ GLAPI void GLAPIENTRY glTexEnvfv (GLenum target, GLenum pname, const GLfloat *pa
GLAPI void GLAPIENTRY glTexImage2D (GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const GLvoid *pixels);
GLAPI void GLAPIENTRY glTexParameterf (GLenum target, GLenum pname, GLfloat param);
GLAPI void GLAPIENTRY glTexSubImage2D (GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const GLvoid *pixels);
-#if !GL_ES_VERSION_2_0 // XXX jwilkins: not in all versions of ES
+#if !GL_ES_VERSION_2_0 // NOTE jwilkins: not in all versions of ES
GLAPI void GLAPIENTRY glTranslatef (GLfloat x, GLfloat y, GLfloat z);
GLAPI void GLAPIENTRY glVertexPointer (GLint size, GLenum type, GLsizei stride, const GLvoid *pointer);
#endif
@@ -627,7 +627,7 @@ GLAPI void GLAPIENTRY glViewport (GLint x, GLint y, GLsizei width, GLsizei heigh
/* --------------------------- GL_ES_VERSION_1_0 --------------------------- */
-#if GL_ES_VERSION_1_0 // XXX jwilkins: should be if not ifdef
+#if GL_ES_VERSION_1_0 // NOTE jwilkins: should be if not ifdef
#define GL_ES_VERSION_1_0 1
typedef void (GLAPIENTRY * PFNGLACTIVETEXTUREPROC) (GLenum texture);
@@ -711,14 +711,14 @@ typedef void (GLAPIENTRY * PFNGLTRANSLATEXPROC) (GLfixed x, GLfixed y, GLfixed z
#define glTranslatex GLEW_GET_FUN(__glewTranslatex)
#else // XXX
-#define GL_ES_VERSION_1_0 0 // XXX jwilkins: define version token
+#define GL_ES_VERSION_1_0 0 // NOTE jwilkins: define version token
#endif /* !GL_ES_VERSION_1_0 */
-#define GLEW_ES_VERSION_1_0 GLEW_GET_VAR(__GLEW_ES_VERSION_1_0) // XXX jwilkins: always needs to be defined
+#define GLEW_ES_VERSION_1_0 GLEW_GET_VAR(__GLEW_ES_VERSION_1_0) // NOTE jwilkins: always needs to be defined
/* -------------------------- GL_ES_VERSION_CL_1_1 ------------------------- */
-#if GL_ES_VERSION_CL_1_1 // XXX jwilkins: should be if not ifdef
+#if GL_ES_VERSION_CL_1_1 // NOTE jwilkins: should be if not ifdef
#define GL_ES_VERSION_CL_1_1 1
#define GL_VERSION_ES_CL_1_1 0x1
@@ -897,14 +897,14 @@ typedef void (GLAPIENTRY * PFNGLTEXPARAMETERXVPROC) (GLenum, GLenum, const GLfi
#define glTexParameterxv GLEW_GET_FUN(__glewTexParameterxv)
#else // XXX
-#define GL_ES_VERSION_CL_1_1 0 // XXX jwilkins: define version token
+#define GL_ES_VERSION_CL_1_1 0 // NOTE jwilkins: define version token
#endif /* !GL_ES_VERSION_CL_1_1 */
-#define GLEW_ES_VERSION_CL_1_1 GLEW_GET_VAR(__GLEW_ES_VERSION_CL_1_1) // XXX jwilkins: always needs to be defined
+#define GLEW_ES_VERSION_CL_1_1 GLEW_GET_VAR(__GLEW_ES_VERSION_CL_1_1) // NOTE jwilkins: always needs to be defined
/* -------------------------- GL_ES_VERSION_CM_1_1 ------------------------- */
-#if GL_ES_VERSION_CM_1_1 // XXX jwilkins: should be if not ifdef
+#if GL_ES_VERSION_CM_1_1 // NOTE jwilkins: should be if not ifdef
#define GL_ES_VERSION_CM_1_1 1
#define GL_VERSION_ES_CM_1_1 0x1
@@ -933,14 +933,14 @@ typedef void (GLAPIENTRY * PFNGLTEXPARAMETERFVPROC) (GLenum, GLenum , const GLf
#define glTexParameterfv GLEW_GET_FUN(__glewTexParameterfv)
#else // XXX
-#define GL_ES_VERSION_CM_1_1 0 // XXX jwilkins: define version token
+#define GL_ES_VERSION_CM_1_1 0 // NOTE jwilkins: define version token
#endif /* !GL_ES_VERSION_CM_1_1 */
-#define GLEW_ES_VERSION_CM_1_1 GLEW_GET_VAR(__GLEW_ES_VERSION_CM_1_1) // XXX jwilkins: always needs to be defined
+#define GLEW_ES_VERSION_CM_1_1 GLEW_GET_VAR(__GLEW_ES_VERSION_CM_1_1) // NOTE jwilkins: always needs to be defined
/* --------------------------- GL_ES_VERSION_2_0 --------------------------- */
-#if GL_ES_VERSION_2_0 // XXX jwilkins: should be if not ifdef
+#if GL_ES_VERSION_2_0 // NOTE jwilkins: should be if not ifdef
#define GL_ES_VERSION_2_0 1
#define GL_NONE 0
@@ -1084,7 +1084,7 @@ typedef void (GLAPIENTRY * PFNGLTEXPARAMETERFVPROC) (GLenum, GLenum , const GLf
#define GL_DYNAMIC_DRAW 0x88E8 // XXX missing enum
#define GL_SAMPLE_BUFFERS 0x80A8 // XXX missing enum
-typedef char GLchar; // XXX jwilkins: this typedef is missing when ES 1.1 is not enabled
+typedef char GLchar; // NOTE jwilkins: this typedef is missing when ES 1.1 is not enabled
typedef khronos_intptr_t GLintptr; // XXX
typedef khronos_ssize_t GLsizeiptr; // XXX
@@ -1173,17 +1173,17 @@ typedef void (GLAPIENTRY * PFNGLVERTEXATTRIB4FPROC) (GLuint indx, GLfloat x, GL
typedef void (GLAPIENTRY * PFNGLVERTEXATTRIB4FVPROC) (GLuint indx, const GLfloat* values);
typedef void (GLAPIENTRY * PFNGLVERTEXATTRIBPOINTERPROC) (GLuint indx, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const GLvoid* ptr);
-typedef void (GLAPIENTRY * PFNGLBINDBUFFERPROC) (GLenum , GLuint ); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLBUFFERDATAPROC) (GLenum , GLsizeiptr, const GLvoid *, GLenum ); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLBUFFERSUBDATAPROC) (GLenum, GLintptr, GLsizeiptr, const GLvoid *); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLDELETEBUFFERSPROC) (GLsizei , const GLuint *); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLGENBUFFERSPROC) (GLsizei, GLuint *); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLTEXPARAMETERIPROC) (GLenum, GLenum, GLint); // XXX jwilkins: missing function
-typedef GLboolean (GLAPIENTRY * PFNGLISENABLEDPROC) (GLenum); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLGETFLOATVPROC) (GLenum , GLfloat *); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLDEPTHRANGEFPROC) (GLclampf zNear, GLclampf zFar); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLACTIVETEXTUREPROC) (GLenum texture); // XXX jwilkins: missing function
-typedef void (GLAPIENTRY * PFNGLGETBOOLEANVPROC) (GLenum, GLboolean *); // XXX jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLBINDBUFFERPROC) (GLenum , GLuint ); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLBUFFERDATAPROC) (GLenum , GLsizeiptr, const GLvoid *, GLenum ); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLBUFFERSUBDATAPROC) (GLenum, GLintptr, GLsizeiptr, const GLvoid *); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLDELETEBUFFERSPROC) (GLsizei , const GLuint *); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLGENBUFFERSPROC) (GLsizei, GLuint *); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLTEXPARAMETERIPROC) (GLenum, GLenum, GLint); // NOTE jwilkins: missing function
+typedef GLboolean (GLAPIENTRY * PFNGLISENABLEDPROC) (GLenum); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLGETFLOATVPROC) (GLenum , GLfloat *); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLDEPTHRANGEFPROC) (GLclampf zNear, GLclampf zFar); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLACTIVETEXTUREPROC) (GLenum texture); // NOTE jwilkins: missing function
+typedef void (GLAPIENTRY * PFNGLGETBOOLEANVPROC) (GLenum, GLboolean *); // NOTE jwilkins: missing function
#define glAttachShader GLEW_GET_FUN(__glewAttachShader)
#define glBindAttribLocation GLEW_GET_FUN(__glewBindAttribLocation)
@@ -1270,17 +1270,17 @@ typedef void (GLAPIENTRY * PFNGLGETBOOLEANVPROC) (GLenum, GLboolean *); // XXX
#define glVertexAttrib4fv GLEW_GET_FUN(__glewVertexAttrib4fv)
#define glVertexAttribPointer GLEW_GET_FUN(__glewVertexAttribPointer)
-#define glBindBuffer GLEW_GET_FUN(__glewBindBuffer) // XXX jwilkins: missing function
-#define glBufferData GLEW_GET_FUN(__glewBufferData) // XXX jwilkins: missing function
-#define glBufferSubData GLEW_GET_FUN(__glewBufferSubData) // XXX jwilkins: missing function
-#define glDeleteBuffers GLEW_GET_FUN(__glewDeleteBuffers) // XXX jwilkins: missing function
-#define glGenBuffers GLEW_GET_FUN(__glewGenBuffers) // XXX jwilkins: missing function
-#define glTexParameteri GLEW_GET_FUN(__glewTexParameteri) // XXX jwilkins: missing function
-#define glIsEnabled GLEW_GET_FUN(__glewIsEnabled) // XXX jwilkins: missing function
-#define glGetFloatv GLEW_GET_FUN(__glewGetFloatv) // XXX jwilkins: missing function
-#define glDepthRangef GLEW_GET_FUN(__glewDepthRangef) // XXX jwilkins: missing function
-#define glActiveTexture GLEW_GET_FUN(__glewActiveTexture) // XXX jwilkins: missing function
-#define glGetBooleanv GLEW_GET_FUN(__glewGetBooleanv) // XXX jwilkins: missing function
+#define glBindBuffer GLEW_GET_FUN(__glewBindBuffer) // NOTE jwilkins: missing function
+#define glBufferData GLEW_GET_FUN(__glewBufferData) // NOTE jwilkins: missing function
+#define glBufferSubData GLEW_GET_FUN(__glewBufferSubData) // NOTE jwilkins: missing function
+#define glDeleteBuffers GLEW_GET_FUN(__glewDeleteBuffers) // NOTE jwilkins: missing function
+#define glGenBuffers GLEW_GET_FUN(__glewGenBuffers) // NOTE jwilkins: missing function
+#define glTexParameteri GLEW_GET_FUN(__glewTexParameteri) // NOTE jwilkins: missing function
+#define glIsEnabled GLEW_GET_FUN(__glewIsEnabled) // NOTE jwilkins: missing function
+#define glGetFloatv GLEW_GET_FUN(__glewGetFloatv) // NOTE jwilkins: missing function
+#define glDepthRangef GLEW_GET_FUN(__glewDepthRangef) // NOTE jwilkins: missing function
+#define glActiveTexture GLEW_GET_FUN(__glewActiveTexture) // NOTE jwilkins: missing function
+#define glGetBooleanv GLEW_GET_FUN(__glewGetBooleanv) // NOTE jwilkins: missing function
#define GLEW_ES_VERSION_2_0 GLEW_GET_VAR(__GLEW_ES_VERSION_2_0)
@@ -1459,7 +1459,7 @@ typedef void (GLAPIENTRY * PFNGLVERTEXATTRIBDIVISORANGLEPROC) (GLuint index, GLu
#if !defined(GL_ANGLE_texture_usage)
#define GL_ANGLE_texture_usage 1
-#define GL_NONE 0 // XXX jwilkins: had to change this from 0x0000 so it would match other definition of GL_NONE
+#define GL_NONE 0 // NOTE jwilkins: had to change this from 0x0000 so it would match other definition of GL_NONE
#define GL_TEXTURE_USAGE_ANGLE 0x93A2
#define GL_FRAMEBUFFER_ATTACHMENT_ANGLE 0x93A3
@@ -1874,7 +1874,7 @@ typedef GLboolean (GLAPIENTRY * PFNGLISQUERYEXTPROC) (GLuint id);
#if !defined(GL_EXT_robustness)
#define GL_EXT_robustness 1
-#define GL_NO_ERROR 0 // XXX jwilkins: had to change this from 0x0000 so it would math other definition
+#define GL_NO_ERROR 0 // NOTE jwilkins: had to change this from 0x0000 so it would math other definition
#define GL_LOSE_CONTEXT_ON_RESET_EXT 0x8252
#define GL_GUILTY_CONTEXT_RESET_EXT 0x8253
#define GL_INNOCENT_CONTEXT_RESET_EXT 0x8254
@@ -1909,7 +1909,7 @@ typedef void (GLAPIENTRY * PFNGLREADNPIXELSEXTPROC) (GLint x, GLint y, GLsizei w
#endif /* !GL_EXT_sRGB */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
/* --------------------- GL_EXT_separate_shader_objects -------------------- */
#if !defined(GL_EXT_separate_shader_objects)
@@ -2320,9 +2320,9 @@ typedef void (GLAPIENTRY * PFNGLCLIPPLANEFIMGPROC) (GLenum p, GLfloat eqn[4]);
#define GL_DEBUG_SEVERITY_LOW 0x9148
#define GL_DEBUG_OUTPUT 0x92E0
-typedef void (APIENTRY *GLDEBUGPROC)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar* message, GLvoid* userParam); // XXX jwilkins: added this typedef
+typedef void (APIENTRY *GLDEBUGPROC)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar* message, GLvoid* userParam); // NOTE jwilkins: added this typedef
-typedef void (GLAPIENTRY * PFNGLDEBUGMESSAGECALLBACKPROC) (GLDEBUGPROC callback, void* userParam); // XXX jwilkins: had to fix DEBUGPROC
+typedef void (GLAPIENTRY * PFNGLDEBUGMESSAGECALLBACKPROC) (GLDEBUGPROC callback, void* userParam); // NOTE jwilkins: had to fix DEBUGPROC
typedef void (GLAPIENTRY * PFNGLDEBUGMESSAGECONTROLPROC) (GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint* ids, GLboolean enabled);
typedef void (GLAPIENTRY * PFNGLDEBUGMESSAGEINSERTPROC) (GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const char* buf);
typedef GLuint (GLAPIENTRY * PFNGLGETDEBUGMESSAGELOGPROC) (GLuint count, GLsizei bufsize, GLenum* sources, GLenum* types, GLuint* ids, GLenum* severities, GLsizei* lengths, char* messageLog);
@@ -3730,7 +3730,7 @@ struct GLEWContextStruct
{
#endif /* GLEW_MX */
-#if GL_ES_VERSION_1_0 // XXX jwilkins: glew doesn't actually seem to be designed to let you use the extension macros
+#if GL_ES_VERSION_1_0 // NOTE jwilkins: glew doesn't actually seem to be designed to let you use the extension macros
GLEW_FUN_EXPORT PFNGLACTIVETEXTUREPROC __glewActiveTexture;
GLEW_FUN_EXPORT PFNGLALPHAFUNCXPROC __glewAlphaFuncx;
GLEW_FUN_EXPORT PFNGLCLEARCOLORXPROC __glewClearColorx;
@@ -3770,9 +3770,9 @@ GLEW_FUN_EXPORT PFNGLTEXENVXPROC __glewTexEnvx;
GLEW_FUN_EXPORT PFNGLTEXENVXVPROC __glewTexEnvxv;
GLEW_FUN_EXPORT PFNGLTEXPARAMETERXPROC __glewTexParameterx;
GLEW_FUN_EXPORT PFNGLTRANSLATEXPROC __glewTranslatex;
-#endif // XXX jwilkins
+#endif // NOTE jwilkins
-#if GL_ES_VERSION_CL_1_1 // XXX jwilkins
+#if GL_ES_VERSION_CL_1_1 // NOTE jwilkins
GLEW_FUN_EXPORT PFNGLBINDBUFFERPROC __glewBindBuffer;
GLEW_FUN_EXPORT PFNGLBUFFERDATAPROC __glewBufferData;
GLEW_FUN_EXPORT PFNGLBUFFERSUBDATAPROC __glewBufferSubData;
@@ -3801,7 +3801,7 @@ GLEW_FUN_EXPORT PFNGLTEXENVIVPROC __glewTexEnviv;
GLEW_FUN_EXPORT PFNGLTEXPARAMETERIPROC __glewTexParameteri;
GLEW_FUN_EXPORT PFNGLTEXPARAMETERIVPROC __glewTexParameteriv;
GLEW_FUN_EXPORT PFNGLTEXPARAMETERXVPROC __glewTexParameterxv;
-#endif // XXX jwilkins
+#endif // NOTE jwilkins
#if GL_ES_VERSION_CM_1_1 // XXX
GLEW_FUN_EXPORT PFNGLCLIPPLANEFPROC __glewClipPlanef;
@@ -3814,7 +3814,7 @@ GLEW_FUN_EXPORT PFNGLGETTEXPARAMETERFVPROC __glewGetTexParameterfv;
GLEW_FUN_EXPORT PFNGLPOINTPARAMETERFPROC __glewPointParameterf;
GLEW_FUN_EXPORT PFNGLPOINTPARAMETERFVPROC __glewPointParameterfv;
GLEW_FUN_EXPORT PFNGLTEXPARAMETERFVPROC __glewTexParameterfv;
-#endif // XXX jwilkins
+#endif // NOTE jwilkins
GLEW_FUN_EXPORT PFNGLATTACHSHADERPROC __glewAttachShader;
GLEW_FUN_EXPORT PFNGLBINDATTRIBLOCATIONPROC __glewBindAttribLocation;
@@ -3901,18 +3901,18 @@ GLEW_FUN_EXPORT PFNGLVERTEXATTRIB4FPROC __glewVertexAttrib4f;
GLEW_FUN_EXPORT PFNGLVERTEXATTRIB4FVPROC __glewVertexAttrib4fv;
GLEW_FUN_EXPORT PFNGLVERTEXATTRIBPOINTERPROC __glewVertexAttribPointer;
-#if !GL_ES_VERSION_CL_1_1 // XXX jwilkins
-GLEW_FUN_EXPORT PFNGLBINDBUFFERPROC __glewBindBuffer; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLBUFFERDATAPROC __glewBufferData; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLBUFFERSUBDATAPROC __glewBufferSubData; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLDELETEBUFFERSPROC __glewDeleteBuffers; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLGENBUFFERSPROC __glewGenBuffers; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLTEXPARAMETERIPROC __glewTexParameteri; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLISENABLEDPROC __glewIsEnabled; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLGETFLOATVPROC __glewGetFloatv; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLDEPTHRANGEFPROC __glewDepthRangef; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLACTIVETEXTUREPROC __glewActiveTexture; // XXX jwilkins: missing function
-GLEW_FUN_EXPORT PFNGLGETBOOLEANVPROC __glewGetBooleanv; // XXX jwilkins: missing function
+#if !GL_ES_VERSION_CL_1_1 // NOTE jwilkins
+GLEW_FUN_EXPORT PFNGLBINDBUFFERPROC __glewBindBuffer; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLBUFFERDATAPROC __glewBufferData; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLBUFFERSUBDATAPROC __glewBufferSubData; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLDELETEBUFFERSPROC __glewDeleteBuffers; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLGENBUFFERSPROC __glewGenBuffers; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLTEXPARAMETERIPROC __glewTexParameteri; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLISENABLEDPROC __glewIsEnabled; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLGETFLOATVPROC __glewGetFloatv; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLDEPTHRANGEFPROC __glewDepthRangef; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLACTIVETEXTUREPROC __glewActiveTexture; // NOTE jwilkins: missing function
+GLEW_FUN_EXPORT PFNGLGETBOOLEANVPROC __glewGetBooleanv; // NOTE jwilkins: missing function
#endif // XXX
GLEW_FUN_EXPORT PFNGLBEGINPERFMONITORAMDPROC __glewBeginPerfMonitorAMD;
@@ -3985,7 +3985,7 @@ GLEW_FUN_EXPORT PFNGLGETNUNIFORMFVEXTPROC __glewGetnUniformfvEXT;
GLEW_FUN_EXPORT PFNGLGETNUNIFORMIVEXTPROC __glewGetnUniformivEXT;
GLEW_FUN_EXPORT PFNGLREADNPIXELSEXTPROC __glewReadnPixelsEXT;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLEW_FUN_EXPORT PFNGLACTIVESHADERPROGRAMEXTPROC __glewActiveShaderProgramEXT;
GLEW_FUN_EXPORT PFNGLBINDPROGRAMPIPELINEEXTPROC __glewBindProgramPipelineEXT;
GLEW_FUN_EXPORT PFNGLCREATESHADERPROGRAMVEXTPROC __glewCreateShaderProgramvEXT;
diff --git a/extern/glew-es/include/GL/glew.h b/extern/glew-es/include/GL/glew.h
index 57c4086dec3..58d49396c5d 100644
--- a/extern/glew-es/include/GL/glew.h
+++ b/extern/glew-es/include/GL/glew.h
@@ -5472,7 +5472,7 @@ typedef void (GLAPIENTRY * PFNGLSAMPLERPARAMETERIVPROC) (GLuint sampler, GLenum
#endif /* !GL_ARB_seamless_cube_map */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
/* --------------------- GL_ARB_separate_shader_objects -------------------- */
#if !defined(GL_ARB_separate_shader_objects)
@@ -9736,7 +9736,7 @@ typedef void (GLAPIENTRY * PFNGLSECONDARYCOLORPOINTEREXTPROC) (GLint size, GLenu
#endif /* !GL_EXT_secondary_color */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
/* --------------------- GL_EXT_separate_shader_objects -------------------- */
#if !defined(GL_EXT_separate_shader_objects)
@@ -17948,7 +17948,7 @@ GLEW_FUN_EXPORT PFNGLSAMPLERPARAMETERFVPROC __glewSamplerParameterfv;
GLEW_FUN_EXPORT PFNGLSAMPLERPARAMETERIPROC __glewSamplerParameteri;
GLEW_FUN_EXPORT PFNGLSAMPLERPARAMETERIVPROC __glewSamplerParameteriv;
-#if 0 // XXX jwilkins: inconsistencies between ES and Desktop versions
+#if 0 // NOTE jwilkins: inconsistencies between ES and Desktop versions
GLEW_FUN_EXPORT PFNGLACTIVESHADERPROGRAMPROC __glewActiveShaderProgram;
GLEW_FUN_EXPORT PFNGLBINDPROGRAMPIPELINEPROC __glewBindProgramPipeline;
GLEW_FUN_EXPORT PFNGLCREATESHADERPROGRAMVPROC __glewCreateShaderProgramv;
@@ -18849,7 +18849,7 @@ GLEW_FUN_EXPORT PFNGLSECONDARYCOLOR3USEXTPROC __glewSecondaryColor3usEXT;
GLEW_FUN_EXPORT PFNGLSECONDARYCOLOR3USVEXTPROC __glewSecondaryColor3usvEXT;
GLEW_FUN_EXPORT PFNGLSECONDARYCOLORPOINTEREXTPROC __glewSecondaryColorPointerEXT;
-#if 0 // XXX jwilkins: inconsistencies...
+#if 0 // NOTE jwilkins: inconsistencies...
GLEW_FUN_EXPORT PFNGLACTIVEPROGRAMEXTPROC __glewActiveProgramEXT;
GLEW_FUN_EXPORT PFNGLCREATESHADERPROGRAMEXTPROC __glewCreateShaderProgramEXT;
GLEW_FUN_EXPORT PFNGLUSESHADERPROGRAMEXTPROC __glewUseShaderProgramEXT;
@@ -19008,7 +19008,7 @@ GLEW_FUN_EXPORT PFNGLDEBUGMESSAGEINSERTPROC __glewDebugMessageInsert;
GLEW_FUN_EXPORT PFNGLGETDEBUGMESSAGELOGPROC __glewGetDebugMessageLog;
GLEW_FUN_EXPORT PFNGLGETOBJECTLABELPROC __glewGetObjectLabel;
GLEW_FUN_EXPORT PFNGLGETOBJECTPTRLABELPROC __glewGetObjectPtrLabel;
-//GLEW_FUN_EXPORT PFNGLGETPOINTERVPROC __glewGetPointerv; // XXX jwilkins redefinition?
+//GLEW_FUN_EXPORT PFNGLGETPOINTERVPROC __glewGetPointerv; // NOTE jwilkins redefinition?
GLEW_FUN_EXPORT PFNGLOBJECTLABELPROC __glewObjectLabel;
GLEW_FUN_EXPORT PFNGLOBJECTPTRLABELPROC __glewObjectPtrLabel;
GLEW_FUN_EXPORT PFNGLPOPDEBUGGROUPPROC __glewPopDebugGroup;
@@ -19950,7 +19950,7 @@ GLEW_VAR_EXPORT GLboolean __GLEW_ARB_robustness_share_group_isolation;
GLEW_VAR_EXPORT GLboolean __GLEW_ARB_sample_shading;
GLEW_VAR_EXPORT GLboolean __GLEW_ARB_sampler_objects;
GLEW_VAR_EXPORT GLboolean __GLEW_ARB_seamless_cube_map;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLEW_VAR_EXPORT GLboolean __GLEW_ARB_separate_shader_objects;
#endif
GLEW_VAR_EXPORT GLboolean __GLEW_ARB_shader_atomic_counters;
@@ -20093,7 +20093,7 @@ GLEW_VAR_EXPORT GLboolean __GLEW_EXT_provoking_vertex;
GLEW_VAR_EXPORT GLboolean __GLEW_EXT_rescale_normal;
GLEW_VAR_EXPORT GLboolean __GLEW_EXT_scene_marker;
GLEW_VAR_EXPORT GLboolean __GLEW_EXT_secondary_color;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLEW_VAR_EXPORT GLboolean __GLEW_EXT_separate_shader_objects;
#endif
GLEW_VAR_EXPORT GLboolean __GLEW_EXT_separate_specular_color;
diff --git a/extern/glew-es/include/GL/wglew.h b/extern/glew-es/include/GL/wglew.h
index 311d7565144..df68427d809 100644
--- a/extern/glew-es/include/GL/wglew.h
+++ b/extern/glew-es/include/GL/wglew.h
@@ -954,8 +954,8 @@ typedef BOOL (WINAPI * PFNWGLCOPYIMAGESUBDATANVPROC) (HGLRC hSrcRC, GLuint srcNa
#if !defined(WGL_NV_gpu_affinity)
#define WGL_NV_gpu_affinity 1
-#define ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV 0x20D0 // XXX jwilkins: incorrect name
-#define ERROR_MISSING_AFFINITY_MASK_NV 0x20D1 // XXX jwilkins: incorrect name
+#define ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV 0x20D0 // NOTE jwilkins: incorrect name
+#define ERROR_MISSING_AFFINITY_MASK_NV 0x20D1 // NOTE jwilkins: incorrect name
DECLARE_HANDLE(HGPUNV);
typedef struct _GPU_DEVICE {
@@ -1406,8 +1406,8 @@ GLEWAPI GLboolean wglewContextIsSupported (const WGLEWContext* ctx, const char*
#define WGLEW_GET_VAR(x) (*(const GLboolean*)&x)
#define WGLEW_GET_FUN(x) x
-GLEWAPI GLenum wglewContextInit (void); // XXX jwilkins: Why does this require GLEW_MX? Should I enable GLEW_MX? instead?
-#define wglewInit() wglewContextInit() // XXX jwilkins: Why does this require GLEW_MX? Should I enable GLEW_MX? instead?
+GLEWAPI GLenum wglewContextInit (void); // NOTE jwilkins: Why does this require GLEW_MX? Should I enable GLEW_MX? instead?
+#define wglewInit() wglewContextInit() // NOTE jwilkins: Why does this require GLEW_MX? Should I enable GLEW_MX? instead?
GLEWAPI GLboolean wglewIsSupported (const char* name);
diff --git a/extern/glew-es/src/glew.c b/extern/glew-es/src/glew.c
index 080c49ffb25..e13e4c92d65 100644
--- a/extern/glew-es/src/glew.c
+++ b/extern/glew-es/src/glew.c
@@ -97,7 +97,7 @@
#ifdef linux
#include <dlfcn.h>
//XXX jwilkins: to do ?? properly set the lib paths depending on openGL version.
#if defined(GLEW_USE_LIB_ES20)
#define GLEW_OPENGLES_LIB_PATH "/usr/lib/libGLESv2.so"
#elif defined(GLEW_USE_LIB_ES11)
@@ -235,7 +235,7 @@ void* NSGLGetProcAddress (const GLubyte *name)
static HMODULE hLibEGL = NULL;
static HMODULE hLibGLESv2 = NULL;
- void* weGetProcAddress(const char* name) // XXX jwilkins
+ void* weGetProcAddress(const char* name) // NOTE jwilkins
{
void* proc = eglGetProcAddress(name);
@@ -271,7 +271,7 @@ void* NSGLGetProcAddress (const GLubyte *name)
#elif defined(_WIN32)
static HMODULE hOpenGL = NULL;
- void* wGetProcAddress(const char* name) // XXX jwilkins
+ void* wGetProcAddress(const char* name) // NOTE jwilkins
{
void* proc = wglGetProcAddress(name);
@@ -408,7 +408,7 @@ static GLboolean _glewSearchExtension (const char* name, const GLubyte *start, c
return GL_FALSE;
}
#ifndef GLEW_ES_ONLY
- else { // XXX jwilkins: unified extension string is deprecated
+ else { // NOTE jwilkins: unified extension string is deprecated
PFNGLGETSTRINGIPROC pglGetStringi = (PFNGLGETSTRINGIPROC)glewGetProcAddress("glGetStringi");
if (pglGetStringi != NULL) {
@@ -1362,7 +1362,7 @@ PFNGLSAMPLERPARAMETERFVPROC __glewSamplerParameterfv = NULL;
PFNGLSAMPLERPARAMETERIPROC __glewSamplerParameteri = NULL;
PFNGLSAMPLERPARAMETERIVPROC __glewSamplerParameteriv = NULL;
-#if 0 // XXX jwilkins: inconsistencies
+#if 0 // NOTE jwilkins: inconsistencies
PFNGLACTIVESHADERPROGRAMPROC __glewActiveShaderProgram = NULL;
PFNGLBINDPROGRAMPIPELINEPROC __glewBindProgramPipeline = NULL;
PFNGLCREATESHADERPROGRAMVPROC __glewCreateShaderProgramv = NULL;
@@ -2263,7 +2263,7 @@ PFNGLSECONDARYCOLOR3USEXTPROC __glewSecondaryColor3usEXT = NULL;
PFNGLSECONDARYCOLOR3USVEXTPROC __glewSecondaryColor3usvEXT = NULL;
PFNGLSECONDARYCOLORPOINTEREXTPROC __glewSecondaryColorPointerEXT = NULL;
-#if 0 // XXX jwilkins: inconsistencies
+#if 0 // NOTE jwilkins: inconsistencies
PFNGLACTIVEPROGRAMEXTPROC __glewActiveProgramEXT = NULL;
PFNGLCREATESHADERPROGRAMEXTPROC __glewCreateShaderProgramEXT = NULL;
PFNGLUSESHADERPROGRAMEXTPROC __glewUseShaderProgramEXT = NULL;
@@ -2422,7 +2422,7 @@ PFNGLDEBUGMESSAGEINSERTPROC __glewDebugMessageInsert = NULL;
PFNGLGETDEBUGMESSAGELOGPROC __glewGetDebugMessageLog = NULL;
PFNGLGETOBJECTLABELPROC __glewGetObjectLabel = NULL;
PFNGLGETOBJECTPTRLABELPROC __glewGetObjectPtrLabel = NULL;
//PFNGLGETPOINTERVPROC __glewGetPointerv = NULL; // XXX jwilkins: not sure if I'm the one who commented this out
PFNGLOBJECTLABELPROC __glewObjectLabel = NULL;
PFNGLOBJECTPTRLABELPROC __glewObjectPtrLabel = NULL;
PFNGLPOPDEBUGGROUPPROC __glewPopDebugGroup = NULL;
@@ -3240,7 +3240,7 @@ PFNGLMULTIDRAWELEMENTSSUNPROC __glewMultiDrawElementsSUN = NULL;
#else
-#if GL_ES_VERSION_1_0 // XXX jwilkins: glew doesn't actually seem to be designed to let you use the extension macros
+#if GL_ES_VERSION_1_0 // NOTE jwilkins: glew doesn't actually seem to be designed to let you use the extension macros
PFNGLACTIVETEXTUREPROC __glewActiveTexture = NULL;
PFNGLALPHAFUNCXPROC __glewAlphaFuncx = NULL;
PFNGLCLEARCOLORXPROC __glewClearColorx = NULL;
@@ -3280,9 +3280,9 @@ PFNGLTEXENVXPROC __glewTexEnvx = NULL;
PFNGLTEXENVXVPROC __glewTexEnvxv = NULL;
PFNGLTEXPARAMETERXPROC __glewTexParameterx = NULL;
PFNGLTRANSLATEXPROC __glewTranslatex = NULL;
-#endif // XXX jwilkins
+#endif // NOTE jwilkins
-#if GL_ES_VERSION_CL_1_1 // XXX jwilkins
+#if GL_ES_VERSION_CL_1_1 // NOTE jwilkins
PFNGLBINDBUFFERPROC __glewBindBuffer = NULL;
PFNGLBUFFERDATAPROC __glewBufferData = NULL;
PFNGLBUFFERSUBDATAPROC __glewBufferSubData = NULL;
@@ -3311,9 +3311,9 @@ PFNGLTEXENVIVPROC __glewTexEnviv = NULL;
PFNGLTEXPARAMETERIPROC __glewTexParameteri = NULL;
PFNGLTEXPARAMETERIVPROC __glewTexParameteriv = NULL;
PFNGLTEXPARAMETERXVPROC __glewTexParameterxv = NULL;
-#endif // XXX jwilkins
+#endif // NOTE jwilkins
-#if GL_ES_VERSION_CM_1_1 // XXX jwilkins
+#if GL_ES_VERSION_CM_1_1 // NOTE jwilkins
PFNGLCLIPPLANEFPROC __glewClipPlanef = NULL;
PFNGLGETCLIPPLANEFPROC __glewGetClipPlanef = NULL;
PFNGLGETFLOATVPROC __glewGetFloatv = NULL;
@@ -3411,7 +3411,7 @@ PFNGLVERTEXATTRIB4FPROC __glewVertexAttrib4f = NULL;
PFNGLVERTEXATTRIB4FVPROC __glewVertexAttrib4fv = NULL;
PFNGLVERTEXATTRIBPOINTERPROC __glewVertexAttribPointer = NULL;
-#if !GL_ES_VERSION_CL_1_1 // XXX jwilkins: missing function
+#if !GL_ES_VERSION_CL_1_1 // NOTE jwilkins: missing function
PFNGLBINDBUFFERPROC __glewBindBuffer = NULL; // XXX
PFNGLBUFFERDATAPROC __glewBufferData = NULL; // XXX
PFNGLBUFFERSUBDATAPROC __glewBufferSubData = NULL; // XXX
@@ -3611,7 +3611,7 @@ PFNGLBLENDEQUATIONEXTPROC __glewBlendEquationEXT = NULL;
PFNGLMULTIDRAWARRAYSEXTPROC __glewMultiDrawArraysEXT = NULL;
PFNGLMULTIDRAWELEMENTSEXTPROC __glewMultiDrawElementsEXT = NULL;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
PFNGLACTIVESHADERPROGRAMEXTPROC __glewActiveShaderProgramEXT = NULL;
PFNGLBINDPROGRAMPIPELINEEXTPROC __glewBindProgramPipelineEXT = NULL;
PFNGLCREATESHADERPROGRAMVEXTPROC __glewCreateShaderProgramvEXT = NULL;
@@ -3650,7 +3650,7 @@ PFNGLDEBUGMESSAGEINSERTPROC __glewDebugMessageInsert = NULL;
PFNGLGETDEBUGMESSAGELOGPROC __glewGetDebugMessageLog = NULL;
PFNGLGETOBJECTLABELPROC __glewGetObjectLabel = NULL;
PFNGLGETOBJECTPTRLABELPROC __glewGetObjectPtrLabel = NULL;
-PFNGLGETPOINTERVPROC __glewGetPointerv = NULL; // XXX jwilkins: multiple defs
+PFNGLGETPOINTERVPROC __glewGetPointerv = NULL; // NOTE jwilkins: multiple defs
PFNGLOBJECTLABELPROC __glewObjectLabel = NULL;
PFNGLOBJECTPTRLABELPROC __glewObjectPtrLabel = NULL;
PFNGLPOPDEBUGGROUPPROC __glewPopDebugGroup = NULL;
@@ -3801,7 +3801,7 @@ GLboolean __GLEW_ARB_robustness_share_group_isolation = GL_FALSE;
GLboolean __GLEW_ARB_sample_shading = GL_FALSE;
GLboolean __GLEW_ARB_sampler_objects = GL_FALSE;
GLboolean __GLEW_ARB_seamless_cube_map = GL_FALSE;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLboolean __GLEW_ARB_separate_shader_objects = GL_FALSE;
#endif
GLboolean __GLEW_ARB_shader_atomic_counters = GL_FALSE;
@@ -3944,7 +3944,7 @@ GLboolean __GLEW_EXT_provoking_vertex = GL_FALSE;
GLboolean __GLEW_EXT_rescale_normal = GL_FALSE;
GLboolean __GLEW_EXT_scene_marker = GL_FALSE;
GLboolean __GLEW_EXT_secondary_color = GL_FALSE;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLboolean __GLEW_EXT_separate_shader_objects = GL_FALSE;
#endif
GLboolean __GLEW_EXT_separate_specular_color = GL_FALSE;
@@ -4421,7 +4421,7 @@ GLboolean __GLEW_AMD_performance_monitor = GL_FALSE;
GLboolean __GLEW_APPLE_rgb_422 = GL_FALSE;
GLboolean __GLEW_EXT_blend_minmax = GL_FALSE;
GLboolean __GLEW_EXT_multi_draw_arrays = GL_FALSE;
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
GLboolean __GLEW_EXT_separate_shader_objects = GL_FALSE;
#endif // XXX
GLboolean __GLEW_EXT_texture_compression_dxt1 = GL_FALSE;
@@ -6306,7 +6306,7 @@ static GLboolean _glewInit_GL_ARB_sampler_objects (GLEW_CONTEXT_ARG_DEF_INIT)
#endif /* GL_ARB_seamless_cube_map */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_ARB_separate_shader_objects
static GLboolean _glewInit_GL_ARB_separate_shader_objects (GLEW_CONTEXT_ARG_DEF_INIT)
@@ -8324,16 +8324,16 @@ static GLboolean _glewInit_GL_EXT_secondary_color (GLEW_CONTEXT_ARG_DEF_INIT)
#endif /* GL_EXT_secondary_color */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_EXT_separate_shader_objects
static GLboolean _glewInit_GL_EXT_separate_shader_objects (GLEW_CONTEXT_ARG_DEF_INIT)
{
GLboolean r = GL_FALSE;
- r = ((glActiveProgramEXT = (PFNGLACTIVEPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glActiveProgramEXT")) == NULL) || r; // XXX jwilkins: may be modified
- r = ((glCreateShaderProgramEXT = (PFNGLCREATESHADERPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glCreateShaderProgramEXT")) == NULL) || r; // XXX jwilkins: may be modified
- r = ((glUseShaderProgramEXT = (PFNGLUSESHADERPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glUseShaderProgramEXT")) == NULL) || r; // XXX jwilkins: may be modified
+ r = ((glActiveProgramEXT = (PFNGLACTIVEPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glActiveProgramEXT")) == NULL) || r; // NOTE jwilkins: may be modified
+ r = ((glCreateShaderProgramEXT = (PFNGLCREATESHADERPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glCreateShaderProgramEXT")) == NULL) || r; // NOTE jwilkins: may be modified
+ r = ((glUseShaderProgramEXT = (PFNGLUSESHADERPROGRAMEXTPROC)glewGetProcAddress((const GLubyte*)"glUseShaderProgramEXT")) == NULL) || r; // NOTE jwilkins: may be modified
return r;
}
@@ -10540,7 +10540,7 @@ static GLboolean _glewInit_GL_WIN_swap_hint (GLEW_CONTEXT_ARG_DEF_INIT)
#endif /* GL_WIN_swap_hint */
-#if GL_ES_VERSION_1_0 // XXX jwilkins: changed from ifdef
+#if GL_ES_VERSION_1_0 // NOTE jwilkins: changed from ifdef
static GLboolean _glewInit_GL_ES_VERSION_1_0 (GLEW_CONTEXT_ARG_DEF_INIT)
{
@@ -10591,7 +10591,7 @@ static GLboolean _glewInit_GL_ES_VERSION_1_0 (GLEW_CONTEXT_ARG_DEF_INIT)
#endif /* GL_ES_VERSION_1_0 */
-#if GL_ES_VERSION_CL_1_1 // XXX jwilkins: should be 'if' not 'ifdef'
+#if GL_ES_VERSION_CL_1_1 // NOTE jwilkins: should be 'if' not 'ifdef'
static GLboolean _glewInit_GL_ES_VERSION_CL_1_1 (GLEW_CONTEXT_ARG_DEF_INIT)
{
@@ -10631,7 +10631,7 @@ static GLboolean _glewInit_GL_ES_VERSION_CL_1_1 (GLEW_CONTEXT_ARG_DEF_INIT)
#endif /* GL_ES_VERSION_CL_1_1 */
-#if GL_ES_VERSION_CM_1_1 // XXX jwilkins: should be 'if' not 'ifdef'
+#if GL_ES_VERSION_CM_1_1 // NOTE jwilkins: should be 'if' not 'ifdef'
static GLboolean _glewInit_GL_ES_VERSION_CM_1_1 (GLEW_CONTEXT_ARG_DEF_INIT)
{
@@ -10744,17 +10744,17 @@ static GLboolean _glewInit_GL_ES_VERSION_2_0 (GLEW_CONTEXT_ARG_DEF_INIT)
r = ((glVertexAttrib4fv = (PFNGLVERTEXATTRIB4FVPROC)glewGetProcAddress((const GLubyte*)"glVertexAttrib4fv")) == NULL) || r;
r = ((glVertexAttribPointer = (PFNGLVERTEXATTRIBPOINTERPROC)glewGetProcAddress((const GLubyte*)"glVertexAttribPointer")) == NULL) || r;
- r = ((glBindBuffer = (PFNGLBINDBUFFERPROC)glewGetProcAddress((const GLubyte*)"glBindBuffer")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glBufferData = (PFNGLBUFFERDATAPROC)glewGetProcAddress((const GLubyte*)"glBufferData")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glBufferSubData = (PFNGLBUFFERSUBDATAPROC)glewGetProcAddress((const GLubyte*)"glBufferSubData")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glDeleteBuffers = (PFNGLDELETEBUFFERSPROC)glewGetProcAddress((const GLubyte*)"glDeleteBuffers")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glGenBuffers = (PFNGLGENBUFFERSPROC)glewGetProcAddress((const GLubyte*)"glGenBuffers")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glTexParameteri = (PFNGLTEXPARAMETERIPROC)glewGetProcAddress((const GLubyte*)"glTexParameteri")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glIsEnabled = (PFNGLISENABLEDPROC)glewGetProcAddress((const GLubyte*)"glIsEnabled")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glGetFloatv = (PFNGLGETFLOATVPROC)glewGetProcAddress((const GLubyte*)"glGetFloatv")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glDepthRangef = (PFNGLDEPTHRANGEFPROC)glewGetProcAddress((const GLubyte*)"glDepthRangef")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glActiveTexture = (PFNGLACTIVETEXTUREPROC)glewGetProcAddress((const GLubyte*)"glActiveTexture")) == NULL) || r; // XXX jwilkins: missing function
- r = ((glGetBooleanv = (PFNGLGETBOOLEANVPROC)glewGetProcAddress((const GLubyte*)"glGetBooleanv")) == NULL) || r; // XXX jwilkins: missing function
+ r = ((glBindBuffer = (PFNGLBINDBUFFERPROC)glewGetProcAddress((const GLubyte*)"glBindBuffer")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glBufferData = (PFNGLBUFFERDATAPROC)glewGetProcAddress((const GLubyte*)"glBufferData")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glBufferSubData = (PFNGLBUFFERSUBDATAPROC)glewGetProcAddress((const GLubyte*)"glBufferSubData")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glDeleteBuffers = (PFNGLDELETEBUFFERSPROC)glewGetProcAddress((const GLubyte*)"glDeleteBuffers")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glGenBuffers = (PFNGLGENBUFFERSPROC)glewGetProcAddress((const GLubyte*)"glGenBuffers")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glTexParameteri = (PFNGLTEXPARAMETERIPROC)glewGetProcAddress((const GLubyte*)"glTexParameteri")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glIsEnabled = (PFNGLISENABLEDPROC)glewGetProcAddress((const GLubyte*)"glIsEnabled")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glGetFloatv = (PFNGLGETFLOATVPROC)glewGetProcAddress((const GLubyte*)"glGetFloatv")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glDepthRangef = (PFNGLDEPTHRANGEFPROC)glewGetProcAddress((const GLubyte*)"glDepthRangef")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glActiveTexture = (PFNGLACTIVETEXTUREPROC)glewGetProcAddress((const GLubyte*)"glActiveTexture")) == NULL) || r; // NOTE jwilkins: missing function
+ r = ((glGetBooleanv = (PFNGLGETBOOLEANVPROC)glewGetProcAddress((const GLubyte*)"glGetBooleanv")) == NULL) || r; // NOTE jwilkins: missing function
return r;
}
@@ -11800,7 +11800,7 @@ GLenum glewContextInit (GLEW_CONTEXT_ARG_DEF_LIST)
extEnd = extStart + _glewStrLen(extStart);
#ifndef GLEW_ES_ONLY
}
- else { // XXX jwilkins: unified extension string is deprecated
+ else { // NOTE jwilkins: unified extension string is deprecated
extStart = 0;
extEnd = 0;
}
@@ -12218,7 +12218,7 @@ GLenum glewContextInit (GLEW_CONTEXT_ARG_DEF_LIST)
#ifdef GL_ARB_seamless_cube_map
CONST_CAST(GLEW_ARB_seamless_cube_map) = _glewSearchExtension("GL_ARB_seamless_cube_map", extStart, extEnd);
#endif /* GL_ARB_seamless_cube_map */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_ARB_separate_shader_objects
CONST_CAST(GLEW_ARB_separate_shader_objects) = _glewSearchExtension("GL_ARB_separate_shader_objects", extStart, extEnd);
if (glewExperimental || GLEW_ARB_separate_shader_objects) CONST_CAST(GLEW_ARB_separate_shader_objects) = !_glewInit_GL_ARB_separate_shader_objects(GLEW_CONTEXT_ARG_VAR_INIT);
@@ -12722,7 +12722,7 @@ GLenum glewContextInit (GLEW_CONTEXT_ARG_DEF_LIST)
CONST_CAST(GLEW_EXT_secondary_color) = _glewSearchExtension("GL_EXT_secondary_color", extStart, extEnd);
if (glewExperimental || GLEW_EXT_secondary_color) CONST_CAST(GLEW_EXT_secondary_color) = !_glewInit_GL_EXT_secondary_color(GLEW_CONTEXT_ARG_VAR_INIT);
#endif /* GL_EXT_secondary_color */
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_EXT_separate_shader_objects
CONST_CAST(GLEW_EXT_separate_shader_objects) = _glewSearchExtension("GL_EXT_separate_shader_objects", extStart, extEnd);
if (glewExperimental || GLEW_EXT_separate_shader_objects) CONST_CAST(GLEW_EXT_separate_shader_objects) = !_glewInit_GL_EXT_separate_shader_objects(GLEW_CONTEXT_ARG_VAR_INIT);
@@ -13450,13 +13450,13 @@ GLenum glewContextInit (GLEW_CONTEXT_ARG_DEF_LIST)
CONST_CAST(GLEW_WIN_swap_hint) = _glewSearchExtension("GL_WIN_swap_hint", extStart, extEnd);
if (glewExperimental || GLEW_WIN_swap_hint) CONST_CAST(GLEW_WIN_swap_hint) = !_glewInit_GL_WIN_swap_hint(GLEW_CONTEXT_ARG_VAR_INIT);
#endif /* GL_WIN_swap_hint */
-#if GL_ES_VERSION_1_0 // XXX jwilkins: should be 'if' not 'ifdef'
+#if GL_ES_VERSION_1_0 // NOTE jwilkins: should be 'if' not 'ifdef'
if (glewExperimental || GLEW_ES_VERSION_1_0) CONST_CAST(GLEW_ES_VERSION_1_0) = !_glewInit_GL_ES_VERSION_1_0(GLEW_CONTEXT_ARG_VAR_INIT);
#endif /* GL_ES_VERSION_1_0 */
-#if GL_ES_VERSION_CL_1_1 // XXX jwilkins: should be 'if' not 'ifdef'
+#if GL_ES_VERSION_CL_1_1 // NOTE jwilkins: should be 'if' not 'ifdef'
if (glewExperimental || GLEW_ES_VERSION_CL_1_1) CONST_CAST(GLEW_ES_VERSION_CL_1_1) = !_glewInit_GL_ES_VERSION_CL_1_1(GLEW_CONTEXT_ARG_VAR_INIT);
#endif /* GL_ES_VERSION_CL_1_1 */
-#if GL_ES_VERSION_CM_1_1 // XXX jwilkins: should be 'if' not 'ifdef'
+#if GL_ES_VERSION_CM_1_1 // NOTE jwilkins: should be 'if' not 'ifdef'
if (glewExperimental || GLEW_ES_VERSION_CM_1_1) CONST_CAST(GLEW_ES_VERSION_CM_1_1) = !_glewInit_GL_ES_VERSION_CM_1_1(GLEW_CONTEXT_ARG_VAR_INIT);
#endif /* GL_ES_VERSION_CM_1_1 */
#ifdef GL_ES_VERSION_2_0
@@ -17639,7 +17639,7 @@ GLboolean glewIsSupported (const char* name)
continue;
}
#endif
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_ARB_separate_shader_objects
if (_glewStrSame3(&pos, &len, (const GLubyte*)"separate_shader_objects", 23))
{
@@ -18786,7 +18786,7 @@ GLboolean glewIsSupported (const char* name)
continue;
}
#endif
-#if 0 // XXX jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
+#if 0 // NOTE jwilkins: there is an inconsistency between the ES and Non-ES versions of this extension??
#ifdef GL_EXT_separate_shader_objects
if (_glewStrSame3(&pos, &len, (const GLubyte*)"separate_shader_objects", 23))
{
@@ -97,7 +97,7 @@
#ifdef linux
#include <dlfcn.h>
-//XXX jwilkins: to do ?? properly set the lib paths depending on openGL version.
+//NOTE jwilkins: to do ?? properly set the lib paths depending on openGL version.
#if defined(GLEW_USE_LIB_ES20)
#define GLEW_OPENGLES_LIB_PATH "/usr/lib/libGLESv2.so"
@@ -2422,7 +2422,7 @@ PFNGLDEBUGMESSAGEINSERTPROC __glewDebugMessageInsert = NULL;
PFNGLGETOBJECTLABELPROC __glewGetObjectLabel = NULL;
PFNGLGETOBJECTPTRLABELPROC __glewGetObjectPtrLabel = NULL;
-//PFNGLGETPOINTERVPROC __glewGetPointerv = NULL; // XXX jwilkins: not sure if I'm the one who commented this out
+//PFNGLGETPOINTERVPROC __glewGetPointerv = NULL; // NOTE jwilkins: not sure if I'm the one who commented this out
PFNGLOBJECTLABELPROC __glewObjectLabel = NULL;
PFNGLOBJECTPTRLABELPROC __glewObjectPtrLabel = NULL;